@@ -12,4 +12,8 @@ def initialize(registrar):
 misc_ = {
     "add":     ImageFile('www/add.png', globals()),
     "change":  ImageFile('www/change.png', globals()),
+    "forward": ImageFile('www/forward.png', globals()),
+    "back":    ImageFile('www/back.png', globals()),
+    "up":      ImageFile('www/up.png', globals()),
+    "down":    ImageFile('www/down.png', globals()),
     }
